@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; c-indent-level: 8 -*- */
-/* $Id$ */
+/* $Id: tiff2ps.c 3576 2009-04-07 22:20:19Z nshmyrev $ */
 
 /*
  * Copyright (c) 1988-1997 Sam Leffler
@@ -173,8 +173,11 @@ TIFF2PSContext* tiff2ps_context_new(const gchar *filename) {
 	ctx = g_new0(TIFF2PSContext, 1);
 	ctx->filename = g_strdup(filename);
 	ctx->fd = g_fopen(ctx->filename, "w");
-	if (ctx->fd == NULL)
+	if (ctx->fd == NULL) {
+		g_free (ctx->filename);
+		g_free (ctx);
 		return NULL;
+	}
 	ctx->interpolate = TRUE;     /* interpolate level2 image */
 	ctx->PSavoiddeadzone = TRUE; /* enable avoiding printer deadzone */
 	return ctx;
